<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( ! class_exists( 'WC_Email' ) ) {
	return;
}

class WC_Customer_Subscription_Renewal_Reminder extends WC_Email {

  /**
	 * Email method title.
	 *
	 * @var string
	 */
	public $email_body;
  
	/**
	 * Create an instance of the class.
	 *
	 * @access public
	 * @return void
	 */
	function __construct() {
    // Email slug we can use to filter other data.
		$this->id          = 'wc_customer_subscription_renewal_reminder';
		$this->title       = __( 'Subscription Renewal Reminder', 'custom-wc-email' );
		$this->description = __( 'An email sent to the customer before an active subscription expires.', 'custom-wc-email' );
    // For admin area to let the user know we are sending this email to customers.
		$this->customer_email = true;
    $this->bcc = $this->get_option( 'recipient_bcc', '' );
    $this->cc = $this->get_option( 'recipient_cc', '' );
    // Debug log in Woocommerce -> Status -> Log
    $this->logger = wc_get_logger();
    $this->wsrr_options = get_option( 'wsrr_option' );
    $this->email_body     = __( $this->get_email_body(), 'custom-wc-email' );
    // Default Heading
		$this->heading     = __( 'Subscription Renewal Reminder', 'custom-wc-email' );
		// translators: placeholder is {blogname}, a variable that will be substituted when email is sent out
		$this->subject     = sprintf( _x( '%s Subscription Renewal Reminder', 'default email subject for the subscription renewal reminder email sent to the customer', 'custom-wc-email' ), '{blogname}' );
    // Template paths.
		$this->template_html  = 'emails/wc-customer-renewal-reminder.php';
		$this->template_plain = 'emails/plain/wc-customer-renewal-reminder.php';
		$this->template_base  = CUSTOM_WC_EMAIL_PATH . 'templates/';

    // Load Tiny MCE
    add_action( 'admin_enqueue_scripts', array( $this, 'wsrr_load_admin_scripts' ) );
    // Activate Tiny MCE
    add_action('admin_footer', array( $this, 'wsrr_admin_footer' ));

    // Call parent constructor to load any other defaults not explicity defined here
    parent::__construct();
	}
  
  /**
	 * Trigger Function that will send this email to the customer.
	 *
	 * @access public
	 * @return void
	 */
  public function trigger( $order_id, $email = ''  ) {

    if ($this->wsrr_options['wsrr_debug'] == 1 ) {
     //$this->logger->debug( 'After #3:'.$order_id, array( 'source' => 'woocommerce-subscriptions-renewal-reminder' ) );
    }
    //public function trigger( $order_id, $email = '' $order = false ) {
		$this->object = wc_get_order( $order_id );
    //$this->placeholders['{site_title}']          = 'dev';
		if ( version_compare( '3.0.0', WC()->version, '>' ) ) {
			$order_email = $this->object->billing_email;
		} else {
			$order_email = $this->object->get_billing_email();
		}
    if (!empty($email)):
      $order_email = $email;
    endif;
		$this->recipient = $order_email;
		if ( ! $this->is_enabled() || ! $this->get_recipient() ) {
			return;
		}

    if ($this->wsrr_options['wsrr_debug'] == 1 ) {
      //$this->logger->debug( 'After #4:'.$order_id, array( 'source' => 'woocommerce-subscriptions-renewal-reminder' ) );
     }
    add_filter( 'woocommerce_email_headers', array( $this, 'add_bcc_to_custom_email' ), 10, 3 );
		$this->send( $this->get_recipient(), $this->get_subject($order_id), $this->get_content($order_id), $this->get_headers(), $this->get_attachments() );
	}

  /**
	 * Send an email.
	 *
	 * @param string $to Email to.
	 * @param string $subject Email subject.
	 * @param string $message Email message.
	 * @param string $headers Email headers.
	 * @param array  $attachments Email attachments.
	 * @return bool success
	 */
	public function send( $to, $subject, $message, $headers, $attachments ) {
    if ($this->wsrr_options['wsrr_debug'] == 1 ) {
      //$this->logger->debug( 'After #6:'.$order_id, array( 'source' => 'woocommerce-subscriptions-renewal-reminder' ) );
     }
		add_filter( 'wp_mail_from', array( $this, 'get_from_address' ) );
		add_filter( 'wp_mail_from_name', array( $this, 'get_from_name' ) );
		add_filter( 'wp_mail_content_type', array( $this, 'get_content_type' ) );

		$message              = apply_filters( 'woocommerce_mail_content', $this->style_inline( $message ) );
		$mail_callback        = apply_filters( 'woocommerce_mail_callback', 'wp_mail', $this );
		$mail_callback_params = apply_filters( 'woocommerce_mail_callback_params', array( $to, $subject, $message, $headers, $attachments ), $this );
		$return               = $mail_callback( ...$mail_callback_params );

		remove_filter( 'wp_mail_from', array( $this, 'get_from_address' ) );
		remove_filter( 'wp_mail_from_name', array( $this, 'get_from_name' ) );
		remove_filter( 'wp_mail_content_type', array( $this, 'get_content_type' ) );
    if ($this->wsrr_options['wsrr_debug'] == 1 ) {
      //$this->logger->debug( 'After #7:'.$order_id, array( 'source' => 'woocommerce-subscriptions-renewal-reminder' ) );
     }
		return $return;
	}

  /**
   * Adding Headers to email
   * @since 1.5
   */
  public function add_bcc_to_custom_email( $headers, $email_id, $order ) {
    wsrr_logger('HEADERS:'.var_export($headers, true));
    if ( isset($this->id) && $this->id != $email_id || empty( $this->bcc ) ) {
      return $headers;
    }
    if ( ! is_array( $headers ) ) {
      $headers = array( $headers );
    }
    $headers[] = 'cc: '.$this->cc;
    $headers[] = 'Bcc: '.$this->bcc;
      //$headers = "Content-Type:  text/html \r\n";
      //$headers .= 'Reply-to: ' . __('Administrator') . ' <' . get_option( 'admin_email' ) . ">\r\n";
      //$headers .= 'cc: ' . $this->bcc . "\r\n";
      //$headers .= 'Bcc: ' . $this->bcc . "\r\n";
      //wsrr_logger('BCC:'.$this->bcc);
      //wsrr_logger('HEADERS:'.var_export($headers, true));
    return $headers;
  }
  
  /**
	 * Get content html.
	 *
	 * @access public
	 * @return string
	 */
	public function get_content_html() {
		return wc_get_template_html( $this->template_html, array(
			'order'         => $this->object,
			'email_heading' => $this->get_heading(),
			'sent_to_admin' => false,
			'plain_text'    => false,
			'email'			=> $this,
      // Send additional info to the email template.
	    'email_body'	=> $this->email_body
		), '', $this->template_base );
	}

	/**
	 * Get content plain.
	 *
	 * @return string
	 */
	public function get_content_plain() {
		return wc_get_template_html( $this->template_plain, array(
			'order'         => $this->object,
			'email_heading' => $this->get_heading(),
			'sent_to_admin' => false,
			'plain_text'    => true,
			'email'			=> $this,
       // Send additional info to the email template.
	    'email_body'	=> $this->email_body
	     // 'product_name'	=> $this->product_name,
		), '', $this->template_base );
	}
  
	/**
	 * Load Admin Scripts
	 */
  public function wsrr_load_admin_scripts() {
    $screen = get_current_screen();
    if ($screen->base == 'woocommerce_page_wc-settings' && isset($_GET['section']) && $_GET['section'] == 'wc_customer_subscription_renewal_reminder'):
        wp_enqueue_editor();
    endif;
  }

	/**
	 * Load Admin footer
	 */
  public function wsrr_admin_footer() {
    $screen = get_current_screen();
    // Make sure we are on the right page
    if ($screen->base == 'woocommerce_page_wc-settings' && isset($_GET['section']) && $_GET['section'] == 'wc_customer_subscription_renewal_reminder'):
      echo "<script type='text/javascript'>var wsrr_ajaxurl = '".admin_url('admin-ajax.php')."'</script>";
      ?>
      <script>
      jQuery( document ).ready(function() {
        function emailIsValid (email) {
          return /^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(email)
        }
      var editor_id = 'woocommerce_wc_customer_subscription_renewal_reminder_email_body';
      wp.editor.initialize(
        editor_id,
        {
          tinymce: {
        //wpautop: true,
      relative_urls: false ,
      allow_html_in_named_anchor: true,
      allow_unsafe_link_target: true,
      height: 300,
      //valid_elements : 'a[href|target=_blank],strong/b,div[align],br',
      extended_valid_elements : 'img[class|src|border=0|alt|title|hspace|vspace|width|height|align|onmouseover|onmouseout|name]script[src|async|defer|type|charset]',
      convert_urls: false ,
            plugins : 'charmap colorpicker compat3x directionality fullscreen hr image lists media paste tabfocus textcolor wordpress wpautoresize wpdialogs wpeditimage wpemoji wpgallery wplink wptextpattern wpview',
            toolbar1: 'bold italic underline strikethrough | bullist numlist | blockquote hr wp_more | alignleft aligncenter alignright | link unlink | fullscreen | wp_adv',
            toolbar2: 'formatselect alignjustify forecolor | pastetext removeformat charmap | outdent indent | undo redo | wp_help'
          },
          quicktags: true,
          mediaButtons: true,
        }
      );
      // Test Order 
      var test_email_desc = document.createElement('div');
      test_email_desc.innerHTML = '<h4>Send a Test Renewal Email</h4><p>To send a test renewal email, you will need to have an active subscription. The customer will NOT get this email.</p><p>Simply enter the email address and enter active subscription ID below. (Do not include # only order number) You can locate the subscription ID by going to the WooCommerce -> Subscriptions page.</p>';
      var test_email_cont = document.createElement('div');
      test_email_cont.id = 'test_email_cont';
      //document.getElementById('template').appendChild(test_email_cont);
      document.getElementById('template').before(test_email_cont);
      test_email_cont.appendChild(test_email_desc);

      var emaillabel = document.createElement('label'); // Create Label for Name Field
      emaillabel.innerHTML = "Email: "; // Set Field Labels
      test_email_cont.appendChild(emaillabel);

      var test_email_order_email = document.createElement("input");
      test_email_order_email.setAttribute('type', 'text');
      test_email_order_email.id = 'test_email_order_email';
      test_email_cont.appendChild(test_email_order_email);

      var br = document.createElement('br'); 
      test_email_cont.appendChild(br);

      var emaillabel = document.createElement('label'); // Create Label for Name Field
      emaillabel.innerHTML = "Subscription ID: "; // Set Field Labels
      test_email_cont.appendChild(emaillabel);

      var test_email_order_id = document.createElement("input");
      test_email_order_id.setAttribute('type', 'text');
      test_email_order_id.id = 'test_email_order_id';
      test_email_cont.appendChild(test_email_order_id);

      var br2 = document.createElement('br'); 
      test_email_cont.appendChild(br2);

      var test_email_btn = document.createElement("button");
      test_email_btn.innerHTML = "Send Test Email";
      test_email_cont.appendChild(test_email_btn);

      test_email_btn.onclick = function () {
      event.preventDefault();

      var test_email = document.getElementById("test_email_order_email").value;
      var order_id = document.getElementById("test_email_order_id").value;

      if (emailIsValid(test_email) == true ) {
        if (order_id) {
      jQuery.ajax({
        type : "post",
        url : wsrr_ajaxurl,
        data : { 
            action: "infiniteScroll",
            test_email: test_email,
            order_id : order_id
        },
        success: function(response) {
          alert('Test Renewal Email Was Sent To:'+test_email);
                console.log(response);
        },
        error: function(errorThrown) {
          console.log(errorThrown);
        },
        });
        } else {
          alert('Please Enter a Valid Subscription ID');
        }
      } else {
        alert('Invalid email address!');
      }
    };
});


</script>
<style>
#test_email_cont {
  padding: 40px;
  background: #fff;
  width: auto;
  display: flex;
  flex-direction: column;
}
</style>
      <?php
    endif;
  }

  /**
   * Get email content.
   *
   * @return string
   */
  public function get_content($order_id='') {
    $this->sending = true;
    if ( 'plain' === $this->get_email_type() ) {
    $email_content = $this->wsrr_placeholders($order_id, $this->get_content_plain());
    } else {
    $email_content = $this->wsrr_placeholders($order_id, $this->get_content_html());
    }
    return wordwrap( $email_content, 700 );
  }




    /*
	public function get_content2($order_id) {
		$this->sending = true;
		if ( 'plain' === $this->get_email_type() ) {
			$email_content = wordwrap( preg_replace( $this->plain_search, $this->plain_replace, wp_strip_all_tags( $this->get_content_plain() ) ), 70 );
		} else {
			$email_content = $this->get_content_html();
		}
		return $email_content;
	}
	 */



  /**
	 * Subscription Renewal Placeholders
	 *
	 * @since 3.7.0
	 * @return string
	 */
	public function wsrr_placeholders($order_id, $content) {
        // Order Object
        $order = wc_get_order( $order_id );
        // Subscription Object
        $subscription = wcs_get_subscription( $order_id );
        $billing_fname = $order->get_billing_first_name();
        $billing_lname = $order->get_billing_last_name();
        $billing_email = $order->get_billing_email();
        $subscription_items = $this->wsrr_renewal_subscription_items( $order );
        $next_payment_date = $this->wsrr_subscription_dates($subscription, 'next_payment');
        $end_date = $this->wsrr_subscription_dates($subscription, 'end_date');
        $content = str_replace(array(
          '{first_name}',
          '{last_name}',
          '{email}',
          '{subscription_items_plain}',
          '{next_payment_date}',
          '{end_date}',
          '{subscription_items_table}',
          '{site_title}',
        ), array(
          $billing_fname, 
          $billing_lname, 
          $billing_email, 
          $subscription_items,
          $next_payment_date,
          $end_date,
          $this->subscription_information_table($order_id,$subscription),
          $this->get_blogname()
        ), $content);
        return $content;
  }


  /**
	 * Subscription Renewal Placeholders
	 *
	 * @since 3.7.0
	 * @return string
	 */
	public function wsrr_placeholders22222($order_id, $content) {
    // Order Object
    $order = wc_get_order( $order_id );
    // Subscription Object
    $subscription = wcs_get_subscription( $order_id );
    $billing_fname = $order->get_billing_first_name();
    $billing_lname = $order->get_billing_last_name();
    $billing_email = $order->get_billing_email();
    $subscription_items = $this->wsrr_renewal_subscription_items( $order );
    $next_payment_date = $this->wsrr_subscription_dates($subscription, 'next_payment');
    $end_date = $this->wsrr_subscription_dates($subscription, 'end_date');
    $content = str_replace(array(
      '{first_name}',
      '{last_name}',
      '{email}',
      '{subscription_items_plain}',
      '{next_payment_date}',
      '{end_date}',
      '{subscription_items_table}',
      '{site_title}',
    ), array(
      $billing_fname, 
      $billing_lname, 
      $billing_email, 
      $subscription_items,
      $next_payment_date,
      $end_date,
      $this->subscription_information_table($order_id,$subscription),
      $this->get_blogname()
    ), $content);
		return $content;
	}

  /**
  *  {subscription_items}
  *
  * @since 0.1
  * @param $order_id
  */
  public function wsrr_renewal_subscription_items( $order ) {
    $order_items = $order->get_items();
    $subscription_items ='';
    foreach ($order_items as $item_id => $item_data) {
        $product_name = $item_data['name'];
        $item_total = wc_get_order_item_meta($item_id, '_line_total', true);
        $item_period = get_post_meta($order->get_id(), '_billing_period', true);
        $subscription_items.= $product_name.' - $'.$item_total.'/'.$item_period;
    }
    return $subscription_items;
  }

  
  public function subscription_information_table( $order_id,$subscription){
    $is_admin_email ='';
    $order = wc_get_order( $subscription->get_last_order() );
    $subscriptions = wcs_get_subscriptions_for_order( $order, array( 'order_type' => 'any' ) );
    $has_automatic_renewal = false;
    $is_parent_order       = wcs_order_contains_subscription( $order, 'parent' );
    ob_start(); ?>
<div style="margin-bottom: 40px;">
<h2><?php esc_html_e( 'Subscription information', 'woocommerce-subscriptions' ); ?></h2>
<table class="td" cellspacing="0" cellpadding="6" style="width: 100%; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif; margin-bottom: 0.5em;" border="1">
	<thead>
		<tr>
			<th class="td" scope="col" style="text-align:left;"><?php echo esc_html_x( 'ID', 'subscription ID table heading', 'woocommerce-subscriptions' ); ?></th>
			<th class="td" scope="col" style="text-align:left;"><?php echo esc_html_x( 'Start date', 'table heading', 'woocommerce-subscriptions' ); ?></th>
			<th class="td" scope="col" style="text-align:left;"><?php echo esc_html_x( 'End date', 'table heading', 'woocommerce-subscriptions' ); ?></th>
			<th class="td" scope="col" style="text-align:left;"><?php echo esc_html_x( 'Recurring total', 'table heading', 'woocommerce-subscriptions' ); ?></th>
		</tr>
	</thead>
	<tbody>
	<?php foreach ( $subscriptions as $subscription ) : ?>
		<?php $has_automatic_renewal = $has_automatic_renewal || ! $subscription->is_manual(); ?>
		<tr>
			<td class="td" scope="row" style="text-align:left;"><a href="<?php echo esc_url( ( $is_admin_email ) ? wcs_get_edit_post_link( $subscription->get_id() ) : $subscription->get_view_order_url() ); ?>"><?php echo sprintf( esc_html_x( '#%s', 'subscription number in email table. (eg: #106)', 'woocommerce-subscriptions' ), esc_html( $subscription->get_order_number() ) ); ?></a></td>
			<td class="td" scope="row" style="text-align:left;"><?php echo esc_html( date_i18n( wc_date_format(), $subscription->get_time( 'start_date', 'site' ) ) ); ?></td>
			<td class="td" scope="row" style="text-align:left;"><?php echo esc_html( ( 0 < $subscription->get_time( 'end' ) ) ? date_i18n( wc_date_format(), $subscription->get_time( 'end', 'site' ) ) : _x( 'When cancelled', 'Used as end date for an indefinite subscription', 'woocommerce-subscriptions' ) ); ?></td>
			<td class="td" scope="row" style="text-align:left;">
				<?php echo wp_kses_post( $subscription->get_formatted_order_total() ); ?>
				<?php if ( $is_parent_order && $subscription->get_time( 'next_payment' ) > 0 ) : ?>
					<br>
					<small><?php printf( esc_html__( 'Next payment: %s', 'woocommerce-subscriptions' ), esc_html( date_i18n( wc_date_format(), $subscription->get_time( 'next_payment', 'site' ) ) ) ); ?></small>
				<?php endif; ?>
			</td>
		</tr>
	<?php endforeach; ?>
</tbody>
</table>
<?php if ( $has_automatic_renewal && $subscription->get_time( 'next_payment' ) > 0 ) {
	if ( count( $subscriptions ) === 1 ) {
		$subscription   = reset( $subscriptions );
		$my_account_url = $subscription->get_view_order_url();
	} else {
		$my_account_url = wc_get_endpoint_url( 'subscriptions', '', wc_get_page_permalink( 'myaccount' ) );
	}

	printf( '<small>%s</small>', wp_kses_post( sprintf( _n(
		// Translators: Placeholders are opening and closing My Account link tags.
		'This subscription is set to renew automatically using your payment method on file. You can manage or cancel this subscription from your %smy account page%s.',
		'These subscriptions are set to renew automatically using your payment method on file. You can manage or cancel your subscriptions from your %smy account page%s.',
		count( $subscriptions ),
		'woocommerce-subscriptions'
	), '<a href="' . $my_account_url . '">', '</a>' ) ) );
}?>
</div>
<?php
    return ob_get_clean();
  }

  /**
	 * Subscription Renewal Data
	 *
	 * @since 3.7.0
	 * @return string
	 */
  public function wsrr_subscription_dates($subscription, $type, $format='d-m-Y') {

    if ($subscription->get_time( 'next_payment', 'site' ) == 0):
      $next_payment = 'This order will expire on '.esc_html( date_i18n( wc_date_format(), $subscription->get_time( 'end_date', 'site' ) ) ); 
    else:
      $next_payment = esc_html( date_i18n( wc_date_format(), $subscription->get_time( 'next_payment', 'site' ) ) ); 
    endif;

    if ($subscription->get_time( 'end_date', 'site' ) == 0):
      $end_date = '(When cancelled)';
    else:
      $end_date = esc_html( date_i18n( wc_date_format(), $subscription->get_time( 'end_date', 'site' ) ) );
    endif;

    if ($type == 'next_payment'):
      return $next_payment;
      elseif($type == 'end_date'):
      return $end_date;
    endif;
  }

	/**
	 * Default content to show below main email content.
	 *
	 * @since 3.7.0
	 * @return string
	 */
	public function get_default_email_body() {
		return '<p>Hi {first_name},</p>
    <p>Thank you for using our Service for the past year!</p>
    <p>We wanted to remind you that you’ve chosen the automatic renewal option. Your subscription will be renewed for {subscription_items_plain} on {next_payment_date}. <br />If you wish to stick to your current plan, no action is required. If your billing information has changed, you can update your payment details here.</p>
    <p>Our entire team is dedicated to ensuring your experience is first-rate. If you have any questions, concerns, or suggestions, simply reply to this email and we’ll get back to you with a prompt response.</p>
    <p>{subscription_items_table}</p>
    <p>Thank You, <br />{site_title}</p>';
	}

	/**
	 * Return content from the email_body field.
	 *
	 * Displayed above the footer.
	 *
	 * @since 3.7.0
	 * @return string
	 */
	public function get_email_body() {
		$content = $this->get_option( 'email_body', '' );
    if (empty($content)) {
      // Set Default Body Content
      return apply_filters( 'woocommerce_email_email_body_' . $this->id, $this->format_string( $this->get_default_email_body() ), $this->object, $this );
    } else {
		  return apply_filters( 'woocommerce_email_email_body_' . $this->id, $this->format_string( $content ), $this->object, $this );
    }
	}

  /**
	 * Get email subject.
	 *
	 * @return string
	 */
	public function get_subject($order_id='') {
    if ($this->wsrr_options['wsrr_debug'] == 1 ) {
      $this->logger->debug( 'get_subject():'.$order_id, array( 'source' => 'woocommerce-subscriptions-renewal-reminder' ) );
     }

    $subject = $this->get_option( 'subject', '' );
    if (empty($subject)) {
      $subject = $this->wsrr_placeholders($order_id, $this->get_default_subject() );
    } else {
      $subject = $this->wsrr_placeholders($order_id, $this->get_option( 'subject', $this->get_default_subject()) );
    }
    //$subject = str_replace( '{site_title2}',$order_id, $this->get_option( 'subject', $this->get_default_subject() ) );
    //$subject = $this->wsrr_placeholders($order_id, $this->get_option( 'subject', $this->get_default_subject()) );
    if ($this->wsrr_options['wsrr_debug'] == 1 ) {
      //$this->logger->debug( 'After #5:'.$order_id, array( 'source' => 'woocommerce-subscriptions-renewal-reminder' ) );
     }
		return apply_filters( 'woocommerce_email_subject_' . $this->id, $this->format_string( $subject ), $this->object, $this );
	}
  /**
	 * Get default email subject.
	 *
	 * @since  3.1.0
	 * @return string
	 */
	public function get_default_subject() {
		return '{blogname} Subscription Renewal Reminder';
	}


  /**
	 * Get valid recipients.
	 *
	 * @return string
	 */
	public function get_recipient() {
    if ($this->wsrr_options['wsrr_debug'] == 1 ) {
      $this->logger->debug( 'get_recipient():', array( 'source' => 'woocommerce-subscriptions-renewal-reminder' ) );
     }
		$recipient  = apply_filters( 'woocommerce_email_recipient_' . $this->id, $this->recipient, $this->object, $this );
		$recipients = array_map( 'trim', explode( ',', $recipient ) );
		$recipients = array_filter( $recipients, 'is_email' );
		return implode( ', ', $recipients );
	}

  /**
   * Initialize Settings Form Fields
   *
   * @since 0.1
   */
  public function init_form_fields() {
    $this->form_fields = array(
        'enabled'    => array(
            'title'   => 'Enable/Disable',
            'type'    => 'checkbox',
            'label'   => 'Enable this email notification',
            'default' => 'yes'
        ),
        'recipient_cc'          => array(
					'title'       => __( 'CC', 'woocommerce' ),
					'type'        => 'text',
					'description' => __( 'Enter CC (comma separated) if you would like to send a Carbon Copy to additional recipients.', 'woocommerce' ),
					'placeholder' => '',
					'default'     => '',
					'desc_tip'    => true
				),
        'recipient_bcc'          => array(
					'title'       => __( 'BCC', 'woocommerce' ),
					'type'        => 'text',
					'description' => __( 'Enter CC (comma separated) if you would like to send a Blind Carbon Copy to additional recipients.', 'woocommerce' ),
					'placeholder' => '',
					'default'     => '',
					'desc_tip'    => true
				),
        'subject'    => array(
            'title'       => 'Subject',
            'type'        => 'text',
            'description' => sprintf( 'This controls the email subject line. Leave blank to use the default subject: <code>%s</code>.', $this->subject ),
            'placeholder' => '',
            'default'     => ''
        ),
        'heading'    => array(
            'title'       => 'Email Heading',
            'type'        => 'text',
            'description' => sprintf( __( 'This controls the main heading contained within the email notification. Leave blank to use the default heading: <code>%s</code>.' ), $this->heading ),
            'placeholder' => '',
            'default'     => ''
        ),
        'email_type' => array(
            'title'       => 'Email type',
            'type'        => 'select',
            'description' => 'Choose which format of email to send.',
            'default'     => 'html',
            'class'       => 'email_type',
            'options'     => array(
              'plain'     => 'Plain text',
              'html'      => 'HTML',
              'multipart' => 'Multipart',
            )
        ),
        'email_body'  => array(
            'title'       => 'Email Body',
            'type'        => 'textarea',
            'description' => sprintf( 'Main email body area, place any placeholder, text or images here. HTML and inline styles supported (under the "Text" Tab).<br>Available Placeholders:<b>{first_name}</b>, <b>{last_name}</b>, <b>{email}</b>, <b>{subscription_items_plain}</b>, <b>{next_payment_date}</b>, <b>{end_date}</b>, <b>{subscription_items_table}</b>, <b>{site_title}</b>', esc_attr( get_option( 'admin_email' ) ) ),
            'placeholder' => '',
            'default'     => $this->get_default_email_body(),
        ),
            /*
            'additional_content' => array(
              'title'       => __( 'Additional content', 'woocommerce' ),
              'description' => __( 'Text to appear below the main email content.', 'woocommerce' ) . ' ' . $placeholder_text,
              'css'         => 'width:400px; height: 75px;',
              'placeholder' => __( 'N/A', 'woocommerce' ),
              'type'        => 'textarea',
              'default'     => $this->get_default_additional_content(),
              'desc_tip'    => true,
            ),
            */
    );
  }

} // end class WC_Customer_Subscription_Renewal_Reminder